package runner

const (
	DefaultPortTimeoutSynScan     = 1000
	DefaultPortTimeoutConnectScan = 5000

	DefaultRateSynScan     = 1000
	DefaultRateConnectScan = 1500

	DefaultRetriesSynScan     = 3
	DefaultRetriesConnectScan = 3

	SynScan             = "s"
	ConnectScan         = "c"
	DefautStatsInterval = 5
)
